/**
 * @file
 * Custom JavaScript for the subscriptions page.
 */

(function ($) {
  Drupal.behaviors.subscriptions = {

    $code_text_fld: null,
    $code_btn: null,
    code_length: 19,
    full_length: false,

    attach: function (context, settings) {
      var $activation = $('.page-activation', context);
      if ($activation.length === 0 ) {
        return;
      }
      var $code_text_fld = $('.form-item-code #edit-code', context);
      var $subscription_error_text = $('.subscription-error-text', context);
      var $code_btn = $('.activation-code-btn', context);
      var $close_window_btn = $('#close-window-activation-btn',context);
      var $show_help = $('.find-activation-code',context);
      var $hide_help = $('.close-activation-code-help',context);
      var $address = $('.js-checkout-billing-address', context);
      var $city = $('.js-checkout-billing-city', context);
      var $state = $('.js-checkout-billing-state', context);
      var $billing_zip = $('.js-checkout-billing-zip',context);


      if ($billing_zip.length !== 0) {
        Drupal.behaviors.customerInfo.autocomplete($address, $city, $state, $billing_zip);
        var $submit = $('.js-customer-info-submit', context);
        var $firstname = $('.js-checkout-billing-firstname', context);
        var $lastname = $('.js-checkout-billing-lastname', context);
        var $address = $('.js-checkout-billing-address', context);
        var $address_2 = $('.js-checkout-billing-address-2', context);
        var $city = $('.js-checkout-billing-city', context);
        var $state = $('.js-checkout-billing-state', context);
        var $zip = $('.js-checkout-billing-zip', context);
        var $where = $('.js-activate-where', context);
        var $usage = $('.js-activate-usage', context);

        var $profile_fields = [$firstname, $lastname, $address, $city, $state, $zip, $where, $usage];

        var that = this;

        $submit.on('click', function(e) {
          var validation = that.validateProfileInfo($profile_fields);
          if (!validation) {
            e.preventDefault();
          }
        });

      }

      if ($code_text_fld.length !== 0) {



        $code_text_fld.mask("AAAA-AAAA-AAAA-AAAA", {placeholder: "XXXX-XXXX-XXXX-XXXX"});

        var that = this;

        $code_btn.on('click', function(e) {
          if (!that.validate($code_text_fld.val())) {
            e.preventDefault();
          }
        });

        $code_text_fld.keyup(function () {
          if ($code_text_fld.val().length === that.code_length) {
            this.full_length = true;
            if (that.validate($code_text_fld.val())) {
              $code_text_fld.addClass('completed');
              $code_btn.removeClass('disabled');
              $code_text_fld.removeClass('error');
              $subscription_error_text.hide();
            }
          }
          else {
            $code_text_fld.removeClass('completed');
            $code_btn.addClass('disabled');
          }
        });
        
        var $error = $(".messages.error");
        var error_code = $.cookie("qkn_activation_flow");

        if (error_code) {
          $.cookie("qkn_activation_flow","",0);

          var error_messages = {'QCS-0400-8' : 'Sorry, this code has already been activated.',
            'QCS-0401-2': 'There was an authorization error, please sign in again.',
            'CODE_UNRECOGNIZED': 'That is not a valid activation code.<br/>Please check your activation code and try again.',
            'CODE_UNAVAILABLE': 'This code has already been redeemed Please <br/> <a href="/support">contact customer support<a/> for more information.',
            'CODE_EXPIRED': 'This code has expired Please <br/> <a href="/support">contact customer support<a/> for more information.',
            'SUBSCRIPTION_CREATION_FAILED': 'The call to the subscription service failed, please try again later.',
            'QCS-0500-1' : 'An unknown error occurred please try again.'};

          $code_text_fld.addClass('error');

          var message = error_messages[error_code] || 'An unknown error occurred please try again.';

          $subscription_error_text.html(message);
          $subscription_error_text.show();
        }
        else {
          $code_text_fld.keyup();
        }
      }


      var $renew_link = $('.js-renewal-trigger', context);
      var $renew_copy = $('.js-renewal-copy', context);

      $renew_link.click(function (e) {
        e.preventDefault();

        if ($renew_copy.is(":visible")) {
          return;
        }

        $renew_copy.fadeIn(300, function(){
          $renew_copy.focus();
        });
      });

      $renew_copy.blur(function (e) {
        $renew_copy.fadeOut(300);
      });

      $show_help.click(function (e) {
        e.preventDefault();
        $('.find-activation-code').fadeOut('slow', function(){
          $('.help-box').slideDown();
        });

      });

      $hide_help.click(function(e) {
        e.preventDefault();
        $('.help-box').slideUp(function() {
          $('.find-activation-code').fadeIn();
        });

      });
    },

    isEmpty: function(e) {
      return e === null || e === '';
    },

    showError: function(field) {
      var msg = field.parent().next('.js-customer-info-error');
      msg.removeClass('hidden');
      field.addClass('error');
    },

     validateProfileInfo: function($profile_fields) {
       var success = true;

       for (var i = 0; i < $profile_fields.length; i++) {
         var field = $profile_fields[i];

         if (this.isEmpty(field.val())) {
           this.showError(field);
           success = false;
         }
       }
       return success;
     },

    validate: function(val) {

      val = val.toUpperCase();
      val = val.replace(/-/g,'');

      var checksum = val.charAt(val.length -1);
      var check = ['3','4','6','7','9','A','C','D','E','F','G','H','J','K','L','M','N','P','Q','R','T','U','V','W','X','Y'];

      val = val.slice(0, -1);

      var checkCode = this.getFletcher16Checksum(this.toByteArray(val));

      var checkPos = (checkCode % 26);
      return (check[checkPos] === checksum);
    },

    toByteArray: function(str) {
      var bytes = [];
      var charCode;

      for (var i = 0; i < str.length; ++i) {
        charCode = str.charCodeAt(i);
        bytes.push(charCode & 0xFF);
      }
      return bytes;
    },

    getFletcher16Checksum: function(buf) {
      var sum1 = 0xff, sum2 = 0xff;
      var i = 0;
      var len = buf.length;

      while (len) {
        var tlen = len > 20 ? 20 : len;
        len -= tlen;
        do {
          sum2 += sum1 += buf[i++];
        } while (--tlen);
        sum1 = (sum1 & 0xff) + (sum1 >> 8);
        sum2 = (sum2 & 0xff) + (sum2 >> 8);
      }
      /* Second reduction step to reduce sums to 8 bits */
      sum1 = (sum1 & 0xff) + (sum1 >> 8);
      sum2 = (sum2 & 0xff) + (sum2 >> 8);
      return sum2 << 8 | sum1;
    }
  };
})(jQuery);
;
/**
 * @file
 * Custom JavaScript for Quicken Ajax module.
 */

(function($) {
  Drupal.behaviors.quicken_ajax = {
    attach : function(context, settings) {
      $('body', context).once(function() {
        Drupal.behaviors.quicken_ajax.requestData(context);
      });
    },
    requestData: function(context) {
      if (typeof Drupal.settings.quicken_ajax != 'undefined'
       && typeof Drupal.settings.quicken_ajax.ajax_keys != 'undefined'
       && typeof Drupal.settings.quicken_ajax.ajax_path != 'undefined') {

        var $post_data = {};
        $post_data['quicken_ajax_keys'] = Drupal.settings.quicken_ajax.ajax_keys;

        var $path = Drupal.settings.quicken_ajax.ajax_path;

        $.post($path, $post_data, function (result, status, ajaxXHR) {
          var keys = Object.keys(result.ajax_data);
          for (var i = 0; i < keys.length; i++) {
            var key = keys[i];
            var value = result.ajax_data[key];

            if (value === "") {
              continue;
            }

            $(key, context).html(value);
          }

          Drupal.behaviors.quicken_cid.callAJAX(context, Drupal.settings);
          Drupal.behaviors.quicken_coupons.callAJAX(context, Drupal.settings);
        });
      }
    }
  };
})(jQuery);
;
/**
 * @file
 * Custom JavaScript for Quicken Akamai module.
 */

(function($) {
  Drupal.behaviors.akamai_popup = {
    attach : function(context, settings) {
      $('body', context).once(function() {
        var $akamai_links = $('.js-akamai-link', context);
        var $body = $('body', context);

        if ($akamai_links.length < 1) {
          return;
        }

        if (Drupal.settings.quicken_akamai.timeout) {
          var akamai_timeout = Drupal.settings.quicken_akamai.timeout * 1000;
          setTimeout(function (){
            if (Drupal.settings.quicken_akamai.timeout_warning_path) {
              $.post(Drupal.settings.quicken_akamai.timeout_warning_path, {}, function(result) {
                var $popup = $(result).appendTo($body);
                $popup.find('.modal-box').show();
              });
            }
          }, akamai_timeout);
        }
      });
    }
  };
})(jQuery);
;
/**
 * @file
 * Activates fancy selects on form elements with the quicken fancy select class.
 */

(function ($) {

  Drupal.behaviors.quickenCareFancySelect = {
    attach: function (context, settings) {
      var selects = [];
      $('.quicken-fancy-select', context).not('.fancy-select-on').each(function(i) {
        selects[i] = new Select({
          el: $(this).get(0),
          className: 'select-theme-default'
        });
        $(this).addClass('fancy-select-on');
      });
    }
  };

})(jQuery);
;
/**
 * @file
 * Custom states behavior for the CARE form.
 */

(function ($) {

  Drupal.behaviors.quickenCareStates = {
    attach: function (context, settings) {

      if (!Drupal.behaviors.quickenCareStates.showPhoneSupport(settings)) {
        $('.intuit-care-phone-hours', context).hide();
      } else {
        $('.intuit-care-phone-number', context).each(function() {
          if (typeof settings.QknPhoneSupport != 'undefined') {
            if (settings.QknPhoneSupport.enabled) {
              $(this).text(function() {
                return $(this).text().replace(/\[phone-support-number\]/, settings.QknPhoneSupport.number);
              });
              $(this).show();
            }
          }
        });
      }

      var formContext = $('.quicken-care-select-flow-form', context);
      if (!formContext.length) {
        return;
      }

      var form = $('.quicken-care-select-flow-form').get(0);
      var careStates = new QuickenCareFormStates(form);

      var CAREChatForm = $('.care-chat-link', context);
      Drupal.behaviors.intuitCareWidget.bootCareChatWidgets(CAREChatForm, settings);
      var waitTimes = $('.care-chat-wait-times', context);
      Drupal.behaviors.intuitCareWidget.bootCareChatWidgets(waitTimes, settings);
      if (CAREChatForm.hasClass('intuit-care-hidden')) {
        $('.form-item', CAREChatForm).add('input[type="submit"]', CAREChatForm).hide();
        CAREChatForm.append('<p>Chat is closed. Please try again later.');
        CAREChatForm.removeClass('intuit-care-hidden');
      }
      // Disable the submit button on the refund form once it is clicked.
      $('.quicken-care-select-flow-form').bind('submit.quickenCARE', function(e) {
        $('.quicken-care-form-refund-block .form-submit').hide();
      });

      $('.js-care-support-wrapper', context).fadeIn();
    },

    /**
     * Determines whether or not phone support is open.
     */
    showPhoneSupport: function(settings) {
      if (typeof settings.QknPhoneSupport == 'undefined') {
        return;
      }

      var times = settings.QknPhoneSupport.times;

      return this.showCareWidget(times);
    },

    /**
     * Calculates whether or not a care service is disabled
     * based on configured times.
     */
    showCareWidget: function(times) {
      var caliTime, caliDate, caliDay, caliMinutes;

      caliTime = moment.tz("America/Los_Angeles");
      caliDate = caliTime.format("M/D/YYYY");
      caliDay = caliTime.format("dddd");
      caliMinutes = parseInt(caliTime.format("H")) * 60 + parseInt(caliTime.format("m"));

      var rulesToCheck = [caliDate, caliDay];
      var len = rulesToCheck.length;
      for (var i = 0; i < len; i++) {
        if (!times.hasOwnProperty(rulesToCheck[i])) {
          continue;
        }

        var candidateRule = times[rulesToCheck[i]];
        if (caliMinutes > candidateRule.open && caliMinutes < candidateRule.close) {
          return true;
        }
        return false;
      }
      return false;
    }

  };

/**
 * Javascript object constructor. The QuickenCareFormState object represents the
 * current state of the care form and is arbiter of what should be hidden/shown.
 *
 * @param object form
 *  The form DOM object, used to scope calls to querySelectorAll.
 */
var QuickenCareFormStates = function(form) {

  /**
   * @var array activeSelectTIDs
   *  And array of the html id attributes for active selects (i.e those that are
   *  visible/toggleable to the user).
   */
  this.activeSelectTIDs = [];

  /**
   * @var object careSelects
   *  An object containing all the available select elements and their wrappers
   *  It is keyed by term id.
   */
   this.careSelects = {};

  /**
   * @var object formContext
   *  The form DOM object, used to scope calls to querySelectorAll and
   *  getElementById.
   */
  this.formContext = form;

  // Build out the careSelects data array. Each item in the array is an object
  // with all relevant information necessary about an available select that this
  // functions behavior is being applied to.
  var selectWrappers = this.formContext.querySelectorAll('.care-form-dynamic-select');
  var len = selectWrappers.length;
  for (var i = 0; i < len; i++) {
    var select = this.getSelectFromWrapper(selectWrappers[i]);
    var tid = this.getTIDFromSelect(select);
    // If somehow there is a tid in there that isn't a number, it means there
    // was some unintentional mucking up of the markup. Rather than just have js
    // fatal later on, we'll just skip the item.
    if (typeof(tid) != 'number') {
      continue;
    }
    if (select.selectedIndex != 0) {
      this.activeSelectTIDs.push(tid);
    }
    // Our nice little object. Makes things very nice & convenient.
    this.careSelects[tid] = {
      "wrapper": selectWrappers[i],
      "select": select,
    };
    select.addEventListener('change', this.updateState.bind(this));
  }
  if (!this.activeSelectTIDs.length) {
    this.activeSelectTIDs = [0];
  }

  this.initializeMetaElements();
  // Add states behavior for the paid support button.
  var psButton = this.formContext.querySelectorAll('.quicken-care-form-paid-support-block .care-paid-support-button')[0];
  var len = psButton.attributes.length;
  for (var i = 0; i < len; i++) {
    if (psButton.attributes[i].name != 'data-buy-support-url') {
      continue;
    }
    var buySupportURL = psButton.attributes[i].value;
    break;
  }
  psButton.addEventListener('click', function(e) {
    window.open(buySupportURL);
  });
  // Do an initial update of the DOM. This is also called each time the internal
  // status mapping is updated.
  this.updateDOMState();
}

/**
 * Update the state of the object in response to a change on a select
 * object.
 */
QuickenCareFormStates.prototype.updateState = function(e) {
  var select = e.srcElement ? e.srcElement : e.target;
  var selectedTID = parseInt(select.options[select.selectedIndex].value);
  var parentTID = this.getTIDFromSelect(select);
  // Process the chat, search, community, paid support, and fast answers blocks.
  this.processSelectionMetaFieldsets(selectedTID);

  if (this.isActiveTID(parentTID)) {
    var tidIndex = this.activeSelectTIDs.indexOf(parentTID);
    // if the changed element is already active, we need to slice off the
    // active array at the point that this changed. This is because if we are
    // 5 selects deep and the user changes the third one up, we need to hide and
    // unset all of the selects below it. What we do is we essentially take a
    // slice of the original array, starting from zero, up to the parent selects
    // tid plus one, since we want to slice off everything after it.
    this.activeSelectTIDs = this.activeSelectTIDs.slice(0, tidIndex + 1);
  }
  this.activeSelectTIDs.push(selectedTID);
  this.updateDOMState();
}

/**
 * Update the DOM to reflect the internal state of the QuickenCareFormStates
 * object.
 */
QuickenCareFormStates.prototype.updateDOMState = function() {
  for (var x in this.careSelects) {
    // If the tid is found in our activeSelectTIDs array, we want make sure it
    // is shown and then continue to the next iteration to skip the part that
    // hides it.
    if (this.isActiveTID(parseInt(x))) {
      this.careSelects[x].wrapper.classList.remove('care-form-hidden');
      continue;
    }
    // Otherwise we have a tid that is valid and is not actively selected. For
    // these items we reset the value of the internal select and hide the div
    // that wraps it.
    this.careSelects[x].wrapper.classList.add('care-form-hidden');
    this.careSelects[x].select.selectedIndex = 0;
    this.careSelects[x].select.selectInstance.update();
    // Process the chat, search, community, paid support, and fast answers blocks.
  }
}

/**
 * Given a wrapper elem with an id, returns the select element inside of it.
 *
 * @param object elem
 *  The wrapper DOM object.
 *
 * @return object
 *  The select element.
 */
QuickenCareFormStates.prototype.getSelectFromWrapper = function(elem) {
  var targetSelect = elem.querySelectorAll(' select');
  return targetSelect.length ? targetSelect[0] : false;
}

/**
 * Given a select element with an id including the tid at the end, returns the
 * tid.
 *
 * @param object select
 *  The select DOM object.
 *
 * @return number
 *  The tid.
 */
QuickenCareFormStates.prototype.getTIDFromSelect = function(select) {
  return parseInt(select.id.split('-').pop());
}

/**
 * Returns whether a given tid is in an active state.
 *
 * @return boolean
 *  true if the tid is active. false if not.
 */
QuickenCareFormStates.prototype.isActiveTID = function(tid) {
  return this.activeSelectTIDs.indexOf(tid) >=0;
}

/**
 * Processes the meta fields (i.e the chat form, community/search blocks, the
 * paid support block, and fast answers) in response to a selection.
 *
 * @param number tid
 *  The tid of a selection.
 */
QuickenCareFormStates.prototype.processSelectionMetaFieldsets = function(tid) {
  // For the Community, Search and Chat form blocks. In this case if the
  // selected tid is not in the careSelects object, it means that this option is
  // the end of an answer trail. In this case we want to show the chat, search,
  // and community fieldsets. Otherwise we hide them.
  var method = 'add';
  if (!this.careSelects[tid] && tid != 0 && !isNaN(tid)) {
    var method = 'remove';
  }
  var metas = ['.quicken-care-form-community-block', '.quicken-care-form-search-block'];
  var len = metas.length;
  for (var i = 0; i < len; i++) {
    this.formContext.querySelectorAll(metas[i])[0].classList[method]('care-form-hidden');
  }
  var forms = ['.quicken-care-form-chat-block', '.quicken-care-form-refund-block'];
  var len = forms.length;
  for (var i = 0; i < len; i++) {
    var frm = this.formContext.querySelectorAll(forms[i])[0];
    var regex = new RegExp('care-support-form-' + tid + ' ', 'g');
    var classMatches = frm.className.match(regex);
    if (method == 'remove' && classMatches != null && classMatches.length) {
      frm.classList.remove('care-form-hidden');
      continue;
    }
    frm.classList.add('care-form-hidden');
  }
  // For the paid support block, we first hide it, then check for a class on it
  // that has the tid. If we find one, we'll show it.
  this.formContext.querySelectorAll('.quicken-care-form-paid-support-block')[0].classList.add('care-form-hidden');
  var paidSupport = this.formContext.querySelectorAll('.care-paid-support-' + tid);
  // This grabs the support order number field label so that we can toggle the
  // required span that is added to it.
  var soFieldLabel = this.formContext.querySelectorAll('.quicken-care-form-chat-block .form-item-dynamic-col-2-chat-form-support-order-number label')[0];
  var requiredLabel = soFieldLabel.querySelectorAll('.form-required');
  if (requiredLabel.length) {
    soFieldLabel.removeChild(requiredLabel[0]);
  }
  if (paidSupport.length && !this.careSelects[tid] && tid != 0 && !isNaN(tid)) {
    this.formContext.querySelectorAll('.quicken-care-form-chat-block')[0].classList.remove('care-form-hidden');
  }
  // Lastly, for fast answers, we'll hide all fast answers, then we'll just
  // check for a unique id that has the tid in it.
  var fastAnswers = this.formContext.querySelectorAll('.care-form-fast-answers-block');
  var len = fastAnswers.length;
  for (var i = 0; i < len; i++) {
    fastAnswers[i].classList.add('care-form-hidden');
  }
  var tidAnswers = document.getElementById('care-fast-answers-term-' + tid);
  if (tidAnswers) {
    tidAnswers.classList.remove('care-form-hidden');
  }

  // User Notifications
  var userNotifications = this.formContext.querySelectorAll('.field-name-field-user-notification');
  for (var i = 0; i < userNotifications.length; i++) {
    userNotifications[i].classList.add('care-form-hidden');
  }

  if (tid) {
    var currentNotification = document.getElementsByClassName('user-notification-' + tid);
    if (currentNotification.length) {
      currentNotification[0].classList.remove('care-form-hidden');
    }
  }

  // Stub code to display these specific messages for now.
  // @TODO Refactor.
  var noAccountTIDs = [141, 561, 981, 1831, 2671, 3091, 3511, 4361, 4781, 5516, 5936, 6781];
  var noReceiptTIDs = [146, 566, 986, 1836, 2676, 3096, 3516, 4366, 4786, 5521, 5941, 6786];
  var messageBlocks = $('.quicken-care-form-message-block').addClass('care-form-hidden');
  if (noReceiptTIDs.indexOf(tid) >= 0) {
    $('.quicken-care-msg-no-receipt').removeClass('care-form-hidden');
  }
  if (noAccountTIDs.indexOf(parseInt(tid)) >= 0) {
    $('.quicken-care-msg-create-account').removeClass('care-form-hidden');
  }
}

/**
 * Searchs the active tids for a lowest level match, i.e.
 */
QuickenCareFormStates.prototype.initializeMetaElements = function() {
  var len = this.activeSelectTIDs.length;
  for (var i = 0; i < len; i++) {
    var select = this.careSelects[this.activeSelectTIDs[i]].select;
    var tid = select.options[select.selectedIndex].value;
    if (!this.careSelects[tid]) {
      this.processSelectionMetaFieldsets(tid);
      break;
    }
  }
}

})(jQuery);
;
/**
 * @file
 * Redirects the page to an ININ chat.
 */

(function ($) {

  Drupal.behaviors.quickenCareChatRedirect = {
    // Selections to PureCloud queue mapping.
    queues: {
      "Quicken for Windows": {
        "Other Versions": {
          "queue": "Web CS Chat",
          "skills": ["Web CS Chat 1", "Web CS Chat 2"]
        },
        "default": {
          "Shopping and Buying": {
            "queue": "Web CS Chat",
            "skills": ["Web CS Chat 1", "Web CS Chat 2"]
          },
          "Using Quicken Mobile or receipt capture": {
            "queue": "Web OLB Chat",
            "skills": ["Web OLB Chat 1", "Web OLB Chat 2"]
          },
          "Install, Conversion, Registration": {
            "queue": "Web GS Chat",
            "skills": ["Web GS Chat 1", "Web GS Chat 2"]
          },
          "Downloading accounts and transactions": {
            "queue": "Web OLB Chat",
            "skills": ["Web OLB Chat 1", "Web OLB Chat 2"]
          },
          "Working with Data and Transactions": {
            "queue": "Web OLB Chat",
            "skills": ["Web OLB Chat 1", "Web OLB Chat 2"]
          },
          "Using Reports": {
            "queue": "Web Tech Chat",
            "skills": ["Web Tech Chat 1", "Web Tech Chat 2"]
          },
          "Tracking Investments": {
            "queue": "Web Invest Chat",
            "skills": ["Web Invest Chat 1", "Web Invest Chat 2"]
          },
          "Using the Planning tools": {
            "queue": "Web Tech Chat",
            "skills": ["Web Tech Chat 1", "Web Tech Chat 2"]
          },
          "default": {
            "queue": "Web Tech Chat",
            "skills": ["Web Tech Chat 1", "Web Tech Chat 2"]
          },
        }
      },
      "Quicken for Mac": {
        "Other Versions": {
          "queue": "Web CS Chat",
          "skills": ["Web CS Chat 1", "Web CS Chat 2"]
        },
        "default": {
          "queue": "Web Mac Chat",
          "skills": ["Web Mac Chat 1", "Web Mac Chat 2"]
        }
      },
      "agent": {
        "queue": "Web Tier 2 Win Chat",
        "skills": ["Web Tier 2 Win Chat 1, Web Tier 2 Win Chat 2"]
      },
      "default": {
        "queue": "Web CS Chat",
        "skills": ["Web CS Chat 1", "Web CS Chat 2"]
      }
    },

    attach: function (context, settings) {
      var self = this;
      var careForm = $('.quicken-care-form-chat-block', context);

      if (!careForm.length) {
        return;
      }

      var $phoneWait = $('.js-intuit-care-phone-wait', context);
      var $chatWait = $('.js-intuit-care-chat-wait', context);

      $phoneWait
        .add($chatWait)
        .text(Drupal.t('Determining wait time...'));

      // Fetch wait times and cache for 5 mins.
      $.ajax({
        type: 'GET',
        url: '/ajax/purecloud/waittimes',
        headers: {
          'Cache-Control': 'max-age=300'
        },
        success: function(data) {
          $phoneWait.text(data.phone + ' minutes');
          $chatWait.text(data.chat + ' minutes');
        }
      });

      $('.quicken-care-chat-request-submit-button', careForm).bind('qknLaunchChatWindow', function(e) {
        var queueSettings = self.determineQueue();

        if (!queueSettings.queue) {
          queueSettings = self.queues.default;
        }

        // Open a Purecloud session.
        // Duplicating code in intuit-care.js, not great.
        // @todo clean up
        var form = $(this).parents('form:first');
        // Get form values
        var userFirstName = $('input[name="dynamic_col_2[chat_form][first_name]"]', form).val();
        var userLastName = $('input[name="dynamic_col_2[chat_form][last_name]"]', form).val();
        var userPhoneNumber = $('input[name="dynamic_col_2[chat_form][phone]"]', form).val();
        var userQuestion = $('textarea[name="dynamic_col_2[chat_form][question]"]', form).val();
        var userEmail = $('input[name="dynamic_col_2[chat_form][email]"]', form).val();

        var chatConfig = {
          "webchatAppUrl": settings.QknPurecloud.app_url,
          "webchatServiceUrl": settings.QknPurecloud.service_url,
          "orgId": settings.QknPurecloud.org_id,
          "orgName": settings.QknPurecloud.org_name,
          "skills": queueSettings.skills,
          "priority": 0,
          "queueName": queueSettings.queue,
          "logLevel": (settings.QknPurecloud.debug) ? "DEBUG":"ERROR",
          "locale": "en",
          "companyLogo": {
            "width": settings.QknPurecloud.logo_width,
            "height": settings.QknPurecloud.logo_height,
            "url": settings.QknPurecloud.logo_path
          },
          "companyLogoSmall": {
            "width": settings.QknPurecloud.small_logo_width,
            "height": settings.QknPurecloud.small_logo_height,
            "url": settings.QknPurecloud.small_logo_path
          },
          "agentAvatar": {
            "width": 462,
            "height": 462,
            "url": "https://dhqbrvplips7x.cloudfront.net/webchat/1.0.23/agent-e202505f.png"
          },
          "userAvatar": {
            "width": 462,
            "height": 462,
            "url": "https://dhqbrvplips7x.cloudfront.net/webchat/1.0.23/agent-e202505f.png"
          },
          "welcomeMessage": "Thanks for chatting.",
          "cssClass": "webchat-frame",
          "css": {
            "width": "100%",
            "height": "100%"
          },
          "data": {
            "firstName": userFirstName,
            "lastName": userLastName,
            "phoneNumber": userPhoneNumber,
            "customField1Label": "Question",
            "customField1": userQuestion,
            "customField2Label": "Email Address",
            "customField2": userEmail
          }
        };

        var windowTitle;
        var $this = $(this);
        // chatConfig.queueName = ((settings.QknPurecloud.debug) ? 'QA_':'') + queueName;
        ININ.webchat.create(chatConfig, function(err, webchat) {
          if (err) {
            $this.html('Sorry, chat is currently not available.');
            'console' in window && console.log(err);
            return;
          }
          webchat.renderPopup({
            width: 700,
            height: 500,
            title: windowTitle
          });
        });

        $(this).prop('disabled', true);
      });

      // Enter key within the chat block should hit the chat submit button, not "Get Answers"
      $('.quicken-care-form-chat-block', context).keypress(function (e) {
        if (e.which === 13) {
          e.preventDefault();
          $('.quicken-care-chat-request-submit-button', context).trigger('click');
        }
      })
    },

    /**
     * Find selected options and the matching queue.
     */
    determineQueue: function() {
      var options = [];
      var currentQueue = this.queues;
      // Can't use context here since it'll never match after the form is submitted.
      var $form = $('.quicken-care-select-flow-form');
      var $selects = $form.find('.care-form-dynamic-select:not(.care-form-hidden)');

      $selects.each(function() {
        var option = $(this).find('select option:selected').text();
        options.push($.trim(option));
      });

      options.forEach(function(option) {
        if (currentQueue[option]) {
          currentQueue = currentQueue[option];
        }
        else if (currentQueue.default) {
          currentQueue = currentQueue.default;
        }
      });

      return currentQueue;
    }
  };


  Drupal.behaviors.quickenCareAgentChatRedirect = {

    // Selections to PureCloud queue mapping.
    // This should really be in configurable settings somewhere.
    // @todo edit settings for mac
    queues: {
      "agent": {
        "mac": {
          "queue": "Web Tier 2 Mac Chat",
          "skills": ["Web Tier 2 Mac Chat 1", "Web Tier 2 Mac Chat 2"]
        },
        "windows": {
          "queue": "Web Tier 2 Win Chat",
          "skills": ["Web Tier 2 Win Chat 1", "Web Tier 2 Win Chat 2"]
        }
      }
    },

    attach: function (context, settings) {

      var self = this;
      $('.quicken-care-agent-chat-request-submit-button', context).bind('qknLaunchAgentChatWindow', function(e) {

        // Open a Purecloud session.
        // Duplicating code in intuit-care.js, not great.
        // @todo clean up
        var form = $(this).parents('form:first');
        // Get form values

        var systemType = $('select[name="system_type"]', form).val();

        // Default, just in case.
        if (systemType !== 'mac' && systemType !== 'windows') {
          systemType ='windows';
        }

        var queueSettings = self.queues.agent[systemType];

        var userFirstName = $('input[name="first_name"]', form).val();
        var userLastName = $('input[name="last_name"]', form).val();
        var userEmail = $('input[name="email"]', form).val();
        var caseOrderNumber = $('input[name="case_order_number"]', form).val();

        var chatConfig = {
          "webchatAppUrl": settings.QknPurecloud.app_url,
          "webchatServiceUrl": settings.QknPurecloud.service_url,
          "orgId": settings.QknPurecloud.org_id,
          "orgName": settings.QknPurecloud.org_name,
          "skills": queueSettings.skills,
          "priority": 0,
          "queueName": queueSettings.queue,
          "logLevel": (settings.QknPurecloud.debug) ? "DEBUG":"ERROR",
          "locale": "en",
          "companyLogo": {
            "width": settings.QknPurecloud.logo_width,
            "height": settings.QknPurecloud.logo_height,
            "url": settings.QknPurecloud.logo_path
          },
          "companyLogoSmall": {
            "width": settings.QknPurecloud.small_logo_width,
            "height": settings.QknPurecloud.small_logo_height,
            "url": settings.QknPurecloud.small_logo_path
          },
          "agentAvatar": {
            "width": 462,
            "height": 462,
            "url": "https://dhqbrvplips7x.cloudfront.net/webchat/1.0.23/agent-e202505f.png"
          },
          "userAvatar": {
            "width": 462,
            "height": 462,
            "url": "https://dhqbrvplips7x.cloudfront.net/webchat/1.0.23/agent-e202505f.png"
          },
          "welcomeMessage": "Thanks for chatting.",
          "cssClass": "webchat-frame",
          "css": {
            "width": "100%",
            "height": "100%"
          },
          "data": {
            "firstName": userFirstName,
            "lastName": userLastName,
            "customField2Label": "Email Address",
            "customField2": userEmail,
            "customField3Label": "Case Order Number",
            "customField3": caseOrderNumber
          },
          "popupNewTab": true,
          "standAloneApplication": true
        };

        var windowTitle;
        var $this = $(this);
        // chatConfig.queueName = ((settings.QknPurecloud.debug) ? 'QA_':'') + queueName;
        ININ.webchat.create(chatConfig, function(err, webchat) {
          if (err) {
            $this.html('Sorry, chat is currently not available.');
            'console' in window && console.log(err);
            return;
          }
          webchat.renderPopup({
            width: 700,
            height: 500,
            title: windowTitle,
            newTab: true
          });
        });

        $(this).prop('disabled', true);
      });
    },

  };


  /**
   * Grabs the users' browsername and version number.
   * @see https://cube3x.com/get-browser-name-and-version-using-pure-javascript/
  */
  var getUserBrowser = function() {
    var N= navigator.appName, ua= navigator.userAgent, tem;
    var M= ua.match(/(opera|chrome|safari|firefox|msie)\/?\s*(\.?\d+(\.\d+)*)/i);
    if(M && (tem= ua.match(/version\/([\.\d]+)/i))!= null) M[2]= tem[1];
    M= M? [M[1], M[2]]: [N, navigator.appVersion,'-?'];
    return M;
  }

})(jQuery);
;
(function($) {

  Drupal.behaviors.chatWindow = {
    attach: function(context, settings) {
      // We only want to add this widget on a vanilla page load.
      var pageLoadContext = $('body', context);
      // If there aren't any chat widgets in settings then there aren't any on
      // the page so we return. We also check against our percentage and any
      // cookies the user may have as an additional 
      var chatWidgets = settings.quicken_chat ? settings.quicken_chat.chatWindows : null;
      if (!chatWidgets || !quickenChatWindowShow(settings) || !pageLoadContext.length) {
        return;
      }

      
      $.getScript('https://quicken.widget.custhelp.com/euf/rightnow/RightNow.Client.js', function() {
        var len = chatWidgets.length;
        for (var i = 0; i < len; i++) {
          quickenChatWindowBuild(chatWidgets[i], i);
        }
      });
    }
  }

/**
 * Makes a decision as to whether a chat window should show for the current
 * user and sets that decision as a cookie in their browser. Once the cookie is
 * set this function will check for that cookie first before making a new 
 * decision.
 *
 * @param object settings
 *  Drupal settings.
 * @return boolean
 *  True if the window should show, false if it should not.
 */
var quickenChatWindowShow = function(settings) {
  var pct = parseFloat(settings.quicken_chat.chatWindowPct);
  if (($.cookie('quicken_support_chat') && $.cookie('quicken_support_chat') < 1) || pct == 0) {
    return false;
  }
  var rand = Math.random();
  var chatCookieVal = rand > pct ? 0 : 1;
  $.cookie('quicken_support_chat', chatCookieVal, {path: "/", domain: Drupal.baseurl, expires: 7});
  return chatCookieVal == 1;
}

/**
 * Builds the chat window and inserts it into the dom.
 *
 * @param object $conf
 *  The chat widget conf from panels.
 * @param number $index
 *  A unique index for the conf, used to ensure that all html ids are unique.
 */
var quickenChatWindowBuild = function($conf, $index) {
  var chatWidget = $('<div class="quickenchatwidget ' + $conf.widget_class + '">');
  chatWidget.append($('<div><span class="qc-ask-community"></span><a href="/community">Ask the community</a></div>'));
  var ids = ['QuickenChatLinkContainer', 'QuickenChatLink', 'QuickenChatLinkInfo'];
  var divs = {};
  var len = ids.length;
  for (var i = 0; i < len; i++) {
    divs[i] = i == 0 ? $('<div class="chatlinkcontainer">') : $('<div>');
    divs[i].attr('id', ids[i] + '-' + $index);
    if (i > 0) {
      divs[i - 1].append(divs[i]);
    }
  }
  chatWidget.append(divs[0]);
  chatWidget.insertAfter($conf.selector);
  
  RightNow.Client.Controller.addComponent(
    {
      container_element_id: 'myChatLinkContainer' + '-' + $index,
      chat_login_page: $conf.agent_path,
      c: $conf.category_id,
      info_element_id: 'QuickenChatLinkInfo' + '-' + $index,
      label_available_immediately_template: "Chat Now",
      link_element_id: 'QuickenChatLink' + '-' + $index,
      wait_threshold: 180,
      instance_id: 'sccl_0',
      module: 'ConditionalChatLink',
      p: $conf.product_id,
      type: 7
    },
    'https://quicken.widget.custhelp.com/ci/ws/get'
  );
}

})(jQuery);
;
/**
 * @file
 * Custom JavaScript to add a CID into the user's session.
 */

(function ($) {
  Drupal.behaviors.quicken_cid = {
    callAJAX: function (context, settings) {
      $('body', context).once(function () {
        if (typeof(Drupal.settings.quicken_cid) === 'undefined') {
          return;
        }

        $.get(Drupal.settings.quicken_cid.get_cid_callback, function (result) {
          if (result.has_cid) {
            return;
          }

          var post_data = {};

          if (QuickenGlobal.isSEO()) {
            post_data.quicken_cid = Drupal.settings.quicken_cid.seo_cid;
          }
          else {
            post_data.quicken_cid = Drupal.settings.quicken_cid.default_cid;
          }

          $.post(Drupal.settings.quicken_cid.set_cid_callback, post_data);
        });
      });
    }
  };
})(jQuery);
;
/**
 * @file
 * Custom JavaScript to add a coupon into the user's session.
 */

(function($) {
  Drupal.behaviors.quicken_coupons = {
    callAJAX : function(context, settings) {
      $('body', context).once(function() {
        if (typeof(Drupal.settings.quicken_coupon) === 'undefined') {
          return;
        }

        $.get(Drupal.settings.quicken_coupon.get_coupon_callback, function (result) {
          if (result.has_coupon) {
            return;
          }

          var post_data = {};

          if (QuickenGlobal.isSEO()) {
            post_data.quicken_coupon_code = Drupal.settings.quicken_coupon.seo_coupon;
          }
          else {
            post_data.quicken_coupon_code = Drupal.settings.quicken_coupon.default_coupon;
          }

          $.post(Drupal.settings.quicken_coupon.set_coupon_callback, post_data, function(data) {
            if (typeof data.success === 'undefined' || data.success === false) {
              return;
            }

            if (typeof Drupal.behaviors.quicken_ajax !== 'undefined') {
              Drupal.behaviors.quicken_ajax.requestData();
            }
          });
        });
      });
    }
  };
})(jQuery);
;
(function($) {
  Drupal.behaviors.quickenWinFaq = {
    attach: function(context, settings) {
      if (!$('.panels-page-windows-faq-page', context).length) {
        return;
      }

      $('.faq-question', context).click(function() {
          $(this).closest('.views-row').find('.faq-answers').toggle('slow');
      });

    }
  };
})(jQuery);
;
var QuickenGlobal = {};

(function($) {
  function isMac() {
    var mac = false;
    var path = window.location.pathname;

    // Check if on a mac page
    if (path.indexOf('/mac') === 0) {
      mac = true;
    }
    if (path.indexOf('/quicken-2015-mac') >= 0) {
      mac = true;
    }

    // Check if we are coming from a seach that had mac in it
    // Bing will send this, looks like yahoo and google don't
    var pos = document.referrer.indexOf('?q=')
    if (pos >= 0) {
      pos = pos + 3;
      if (document.referrer.slice(pos).indexOf('mac') > 0) {
        mac = true;
      }
    }
    return mac;
  }

  function isSEO() {
    var seo = false;
    var ref = document.referrer;
    var pcol = ref.indexOf("://") + 3;

    // Check for google dot com and dot co dot uk etc
    if (ref.indexOf("google.") == pcol || ref.indexOf("www.google.") == pcol) {
      seo = true;
    }
    // bing always redirects back to bing dot com for intl sites
    if (ref.indexOf("bing.com") == pcol || ref.indexOf("www.bing.com") == pcol) {
      seo = true;
    }
    // yahoo does the same as bing except to r.seaarch....
    if (ref.indexOf("r.search.yahoo.com") == pcol) {
      seo = true;
    }
    // duckduckgo is a search engine
    if (ref.indexOf("duckduckgo.") == pcol) {
      seo = true;
    }
    return seo;
  }

  /**
   * Get's user's device from userAgent.
   *
   * @return string
   * The device.
   */
  function quickenUserDevice() {
    var regex = /\(([A-z0-9\s\.]+);/;
    var ua = navigator.userAgent.match(regex);
    if (ua && ua[1]) {
      return ua[1];
    }
    return false;
  }

  /**
   * Get user country code using FreeGeoIP service.
   */
  var quickenGetUserCountry = function() {
    if ($.cookie('qknUserCountry', {'path': '/'}) !== 'string') {
      $.getJSON('//freegeoip.net/json/', function(data) {
        $.cookie('qknUserCountry', data.country_code, {'path': '/'});
        return data.country_code;
      });
    }
    return $.cookie('qknUserCountry', {'path': '/'});
  };

  QuickenGlobal.isSEO = isSEO;
  QuickenGlobal.isMac = isMac;
  QuickenGlobal.userDevice = quickenUserDevice();
  QuickenGlobal.userCountry = quickenGetUserCountry();
  // Evaluate confirmed non-US or CA country
  QuickenGlobal.userIsConfirmedNonUSorCA = function() {
    return typeof this.userCountry == 'string' &&
      this.userCountry.length == 2 &&
      this.userCountry != 'US' &&
      this.userCountry != 'CA';
  };

})(jQuery);

(function($, Drupal, QuickenGlobal) {
  Drupal.behaviors.quickenGlobal = {
    attach: function(context, settings) {
      if (settings.basePath == '/canada/') {
        return;
      }
      // Rewrite compare page links if OS rewrite is enabled.
      // settings.quicken_global is undefined for the imce module because
      // quicken_global_page_build() does not run with imce.
      if ((typeof settings.quicken_global !== 'undefined') && settings.quicken_global.os_redirect_enabled) {
        this.comparePageLinkAlter(context);
      }

      // Fix for Firefox when we redirect to a URL with a fragment.
      // Scrolling after a redirect based on a URL fragment does not work well in Firefox.
      var regex = /Firefox/;
      if (regex.test(navigator.userAgent)) {
        var scroll_id = window.location.hash || null;
        if (scroll_id) {
          var elem = $(scroll_id);

          if (elem.length) {
            var $screen = $('html, body', context);
            var topOffset = parseInt(elem.offset().top);
            var paddingTop = parseInt(elem.css('padding-top'));
            var scrollAmount = topOffset - ($screen.height() - topOffset) - paddingTop;
            $screen.scrollTop(scrollAmount);
          }
        }
      }
    },

    comparePageLinkAlter: function(context) {
      // Paths /compare and /compare/mac need to redirect to /mac/compare for
      // OSX users.
      if (QuickenGlobal.userDevice != 'Macintosh') {
        return;
      }

      // Exclude /front/2017/C test page.
      if ($('body').hasClass('page-2017-homepage-c')) {
        return;
      }

      var comparePageMac = '/mac/compare';
      var regex = /\/compare(\/mac)?$/i;

      // Header primary nav link.
      $('.navbar a[href="/compare"]', context).attr('href', comparePageMac);
      $('#footer .fine-print a[href="/compare"]', context).attr('href', comparePageMac);

      $('.page-home main a:not(.no-os-rewrite)')
        .filter(function() {
          return $(this).attr('href').match(regex) && !$(this).text().match(/windows/i);
        })
        .each(function() {
          $(this).attr('href', comparePageMac);
        });
    }
  };

})(jQuery, Drupal, QuickenGlobal);
;
(function($) {
Drupal.behaviors.quickenLiftAnalytics = {
  attach: function(context, settings) {
    $(document).bind('personalizeDecision', function(e, $optionSet, option, osid, agent_name)  {
      var personalizeOptionSets = settings.personalize.option_sets;
      if (!personalizeOptionSets.hasOwnProperty(osid)) {
        return;
      }
      var liftInfo = [personalizeOptionSets[osid].agent, personalizeOptionSets[osid].label, option];
      $.each(liftInfo, function(i) {
        liftInfo[i] = liftInfo[i].replace(/[^a-z0-9_]/gi, '-').toLowerCase();
      });
      var testVariant = liftInfo.join('_');

      // Now that we have a machine readable name we store this in a way that
      // the custom Javascript added by Adobe DTM can access it and make the
      // Mixpanel call.
      window.wa = window.wa || {};
      window.wa.testCell=testVariant;

      // Add Lift option selection information as query parameters to any
      // external links for tracking on those external platforms.
      var isAbsolute = new RegExp('^(?:[a-z]+:)?//', 'i');
      $('form', context).each(function(i) {
        if (!$(this).attr('action') || !isAbsolute.test($(this).attr('action'))) {
          return;
        }
        $(this).attr('action', addLiftInfoToUrl($(this).attr('action'), liftInfo, osid));
      });

      $('a', context).each(function(i)  {
        if (!$(this).attr('href') || !isAbsolute.test($(this).attr('href'))) {
          return;
        }
        $(this).attr('href', addLiftInfoToUrl($(this).attr('href'), liftInfo, osid));
      });
    });
  }
}

/**
 * Given a url, append query parameters with the lift information if it is.
 */
var addLiftInfoToUrl = function(url, liftInfo, osid)  {
  var qString = '';
  if (url.indexOf('?') < 0) {
    qString += '?';
  }
  else {
    qString += '&';
  }
  qString += 'lift_campaign_' + osid + '=' + liftInfo[0];
  qString += '&lift_option_set_' + osid + '=' + liftInfo[1];
  qString += '&lift_decision_' + osid + '=' + liftInfo[2];
  return url + qString;
}

})(jQuery);
;
/**
 * @file
 * JS for the Quicken Bills page.
 */

(function ($) {

  Drupal.behaviors.quickenBillsPPC = {
    attach: function (context, settings) {
      if (!$('.quicken-bill-pay-ppc-page-2015', context).length) {
        return;
      }

      var mainContent = $('.quicken-bill-pay-ppc-hero-content');
      var overlay = $('.quicken-bill-pay-ppc-hero-overlay-content');
      var ty = $('.quicken-bill-pay-thank-you-overlay-content');
      overlay.hide();
      ty.hide();
      $('.quicken-bill-pay-ppc-callout-button .quicken-bill-pay-ppc-cta-2015').click(function(e) {
        mainContent.hide();
        overlay.show();
      });

      var yesButtons = $('.quicken-bill-pay-ppc-2015-cta-overlay .overlay-cta');
      yesButtons.click(function(e) {
        if ($(this).attr('href') != '#') {
          return;
        }
        overlay.hide();
        ty.show();
      });
    }

    }

})(jQuery);
;
/**
 * @file
 * Enables refund links opening in modal windows throughout the site.
 */
(function ($) {
  Drupal.behaviors.quickenRefunds = {
    attach: function(context) {
      if (context !== document) {
        return;
      }

      var refundFormLinks = $('a[href^="/refunds"]', context);
      if (refundFormLinks.length > 0) {
        refundFormLinks.addClass('ctools-modal-refund-form');
        var url = '/refunds/ajax';

        if (Drupal.ajax.hasOwnProperty(url)) {
          return;
        }

        var elementSettings = {};
        elementSettings.url = url;
        elementSettings.event = 'click';
        elementSettings.progress = { type: 'throbber' };
        Drupal.ajax[url] = new Drupal.ajax(url, refundFormLinks, elementSettings);
        refundFormLinks.addClass('ctools-use-modal-processed');

        // JS to catch ajax complete events.
        refundFormLinks.ajaxComplete(function(event, xhr, settings) {
          // Hide the throbber on the support page when the popup displays.
          if (event.target.className == 'ctools-modal-refund-form ctools-use-modal-processed') {
            $(event.target).next('.ajax-progress.ajax-progress-throbber').remove();
          }
        });
      }
    }
  };

  Drupal.theme.prototype.refundModalHtml = function() {
    return Drupal.settings.quickenRefunds.modalHtml;
  }
})(jQuery);
;
/**
 * @file
 * Extra functionality for InQuira exported content.
 * For example: Collapsable sections, etc.
 */

(function ($) {

  Drupal.behaviors.quickenSupportInQuira = {
    attach: function (context, settings) {
      $('.uaq_msnav', context).click(function(e) {
        e.preventDefault();

        $(this).toggleClass('uaq_arrow_expanded').nextAll('.uaq_collapsed:first').toggle().toggleClass('uaq_expanded');
      });
    }
  };

})(jQuery);
;
/**
 * @file
 * Custom JavaScript for shopping cart page.
 */

(function($) {
  Drupal.behaviors.shoppingcart = {
    attach : function(context, settings) {

      var $shopping_cart_form = $('#quicken-checkout-cart-form', context);
      if ($shopping_cart_form.length < 1) {
        return;
      }

      var $toggle_buttons = $('.js-product-toggle', context);
      var $cart_alert = $('.js-cart-alert', context);
      var $checkout_button = $('.js-checkout-button', context);
      var $qty_control = $('.js-qty-control', context);

      var force_blur = false;
      var auto_click = false;

      if ($toggle_buttons.length > 0) {
        // We need to also check if we have executed this code before as the form
        // uses ajax and the behaviors execute.
        if (context.length) {
          return;
        }

        $toggle_buttons.click(function (e) {
          if ($(this).hasClass('disabled')) {
            e.preventDefault();
            return;
          }

          $toggle_buttons.addClass('disabled');
        });
      }

      if ($cart_alert.length > 0) {
        $cart_alert.delay(3000).fadeOut();
      }

      $qty_control.change(function () {
        force_blur = true;
      });

      $shopping_cart_form.ajaxComplete(function (e, hxr, settings) {
        force_blur = false;
        if (auto_click) {
          $checkout_button.click();
          auto_click = false;
        }
      });

      $checkout_button.click(function (e) {
        // Prevent submission if ajax events have not finished.
        if (force_blur) {
          auto_click = true;
          e.preventDefault();
        }
      });
    }
  };
})(jQuery);
;
/**
 * @file
 * Custom JavaScript for all pages of checkout for general functionality.
 */

(function ($) {
  Drupal.behaviors.checkout = {
    attach: function (context, settings) {

      $(context).on('click','#add-cd-link', function(e) {

            var sku = e.target.getAttribute('data-sku');
            var $overlay = $('.add-item-modal');
            var $link = $('.js-modal-close', $overlay);
            var $modal_box = $('.modal-box', $overlay);
            var $switch_link = $("#switch-path");

            $switch_link.attr('href', $switch_link.attr('href') + '?sku=' + sku);

            $overlay.removeClass('hidden');

            $link.click(function () {
              $overlay.addClass('hidden');
            });

            $overlay.click(function (e) {
              $overlay.addClass('hidden');
            });

            $modal_box.show();
      });
      $(context).on('click','#remove-cd-link', function(e) {

        var sku = e.target.getAttribute('data-sku');
        var return_path = e.target.getAttribute('data-return-path');
        var $switch_link = $("#switch-path");

        window.location.href = $switch_link.attr('href') + '?sku=' + sku + '&return=' + return_path;

      });

      // Show link in a popup.
      $(context).on('click', '.popup-link', function (e) {
        e.preventDefault();
        window.open($(this).prop('href'), "Quicken", "width=500,height=500");
      });

      var $tooltip_trigger = $('.js-subscription-tooltip-trigger', context);
      if ($tooltip_trigger.length > 0) {
        $tooltip_trigger.each(function() {
          var $trigger = $(this);
          var $tooltip = $(this).parent().siblings('.js-subscription-tooltip');
          $trigger.click(function(e) {
            e.preventDefault();

            if ($tooltip.is(":visible")) {
              return;
            }

            $tooltip.fadeIn(300, function() {
              $tooltip.focus();
            });
          });

          $tooltip.blur(function(e) {
            $tooltip.fadeOut(300);
          });
        });
      }
    }
  };
})(jQuery);
;
/**
 * @file
 * Custom JavaScript for the customer information form.
 */

(function($) {
  Drupal.behaviors.customerInfo = {
    autocomplete : function($address, $city, $state, $zip) {
      if ($address.length < 1) {
        return;
      }

      var autocomplete = new google.maps.places.Autocomplete($address[0], {types: ['geocode']});
      autocomplete.addListener('place_changed', function(s) {
        var place = autocomplete.getPlace();

        var componentForm = {
          street_number: {
            key : 'short_name',
            val : null
          },
          route: {
            key : 'long_name',
            val : null
          },
          locality: {
            key : 'long_name',
            val : null
          },
          administrative_area_level_1: {
            key : 'short_name',
            val : null
          },
          postal_code: {
            key : 'short_name',
            val : null
          },
        };

        for (var i = 0; i < place.address_components.length; i++) {
          var addressType = place.address_components[i].types[0];
          if (componentForm[addressType]) {
            var val = place.address_components[i][componentForm[addressType].key];
            componentForm[addressType].val = val;
          }
        }

        var address = {
          'city' : componentForm.locality.val,
          'state' : componentForm.administrative_area_level_1.val,
          'zip' : componentForm.postal_code.val
        }

        if (componentForm.street_number.val == null) {
          address.address = componentForm.route.val;

          $address.addClass('error');
          $address.parent().siblings('.js-customer-info-address-error').removeClass('hidden');
        } else {
          address.address = componentForm.street_number.val + " " + componentForm.route.val;

          $address.removeClass('error');
          $address.parent().siblings('.js-customer-info-address-error').addClass('hidden');
        }

        $address.val(address.address);
        $city.val(address.city);
        $state.val(address.state);
        $zip.val(address.zip);
      });
    },

    attach : function(context, settings) {
      var isCombinedForm = $('body', context).hasClass('checkout-page-customer-info-combined');
      if (isCombinedForm) {
        var formContext = $('#quicken-checkout-customer-info-combined-form', context);
      }
      else {
        var formContext = $('#quicken-checkout-customer-information-form', context);
      }
      if (!formContext.length) {
        return;
      }

      // Scroll to page title.
      if (isCombinedForm) {
        $('html, body', context).animate({
          scrollTop: $('#page-title', context).offset().top
        }, 1000);
      }

      var $shippingTrigger = $('.js-checkout-shipping-toggle', context);
      var $shippingTarget = $('.js-checkout-shipping-form', context);
      var $tooltip = $('.js-tooltip', context);

      var $phone = $('.js-checkout-billing-phone', context);
      var $email = $('.js-checkout-email', context);
      var $firstname = $('.js-checkout-billing-firstname', context);
      var $lastname = $('.js-checkout-billing-lastname', context);
      var $address = $('.js-checkout-billing-address', context);
      var $address_2 = $('.js-checkout-billing-address-2', context);
      var $city = $('.js-checkout-billing-city', context);
      var $state = $('.js-checkout-billing-state', context);
      var $zip = $('.js-checkout-billing-zip', context);

      var $same_as_billing = $('.js-checkout-shipping-toggle', context);

      var $shipping_firstname = $('.js-checkout-shipping-firstname', context);
      var $shipping_lastname = $('.js-checkout-shipping-lastname', context);
      var $shipping_address = $('.js-checkout-shipping-address', context);
      var $shipping_address_2 = $('.js-checkout-shipping-address-2', context);
      var $shipping_city = $('.js-checkout-shipping-city', context);
      var $shipping_state = $('.js-checkout-shipping-state', context);
      var $shipping_zip = $('.js-checkout-shipping-zip', context);

      var $submit = $('.js-customer-info-submit', context);

      var $all_errors = $('.js-customer-info-error', context);

      var $body = $('body', context);

      var canada_postal_code = false;

      if ($zip.length < 1) {
        $zip = $('.js-checkout-billing-zip-ca', context);
        canada_postal_code = true;
      }

      // Add autocomplete for the address fields.
      Drupal.behaviors.customerInfo.autocomplete($address, $city, $state, $zip);
      Drupal.behaviors.customerInfo.autocomplete($shipping_address, $shipping_city, $shipping_state, $shipping_zip);

      $address.on('blur', function() {
        formContext.removeClass('address-validated');
      });

      var $billing_fields = [$firstname, $lastname, $address, $city, $zip];
      var $shipping_fields = [$shipping_firstname, $shipping_lastname, $shipping_address, $shipping_city, $shipping_state, $shipping_zip];

      if (!canada_postal_code) {
        $zip.on('keydown', function(e) {
          validateZip(e, this);
        });

        // Remove letters on blur
        $zip.on('blur', function(e) {
          removeLetters.apply(this);
        });
      }

      function formatPhoneNumber() {
        var val = $phone.val();
        val = val.replace(/\D/g, '');
        val = val.slice(0, 3) + '-' + val.slice(3, 6) + '-' + val.slice(6);
        $phone.val(val);
      }

      $phone.on('blur', function() {
        formatPhoneNumber();
      });

      // Initialize phone tooltip
      $tooltip.tooltip();

      function formatZipCode(event, key, field) {
        var $field = $(field);
        if (!$field.length) {
          return;
        }

        var value = $field.val();
        if (value.length == 5 && key) {
          $field.val(value + '-' + key);
          event.preventDefault();
        }

        value = $field.val();
        if (value.length >= 10) {
          event.preventDefault();
        }
      }

      function validateZip(event, field) {
        var key = String.fromCharCode(event.keyCode);
        if ($.isNumeric(key)) {
          return formatZipCode(event, key, field);
        }

        // Allow the dash (-), the arrow keys, backspace, shift, tab, numpad digits 0-9 and delete keys, as well as cmd/ctrl and v for pasting.
        var allowed_keys = [189, 37, 39, 8, 46, 9, 16, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 17, 91, 86];
        if (allowed_keys.indexOf(event.keyCode) >= 0) {
          return;
        }

        // Allow key combinations
        if (e.ctrlKey) {
          if (e.key == 'a' || e.key == 'x' || e.key == 'z') {
            return;
          }
        }

        if (e.shiftKey) {
          if (e.key == 'Home') {
            return;
          }
        }

        if (e.key == 'Home') {
          return;
        }

        event.preventDefault();
      }

      function removeLetters() {
        if (this.value.match(/^[0-9]{5}-[0-9]{4}/)) {
          return this.value.match;
        }
        return this.value = this.value.replace(/[^0-9]/g, '');
      }

      $shippingTrigger.on('change', function() {
        $shippingTarget.toggleClass('active', !$shippingTrigger.is(':checked'));
      });

      // Show or hide the shipping form based on the initial state of the checkbox.
      $shippingTarget.toggleClass('active', !$shippingTrigger.attr('checked'));

      $shipping_zip.on('keydown', function(e) {
        validateZip(e, this)
      });

      $shipping_zip.on('blur', function(e) {
        removeLetters.apply(this);
      });

      function isEmpty(e) {
        return e === null || e === '';
      }

      function showError(field) {
        var msg = field.parent().next('.js-customer-info-error');
        msg.removeClass('hidden');
        field.addClass('error');
      }

      function validateCustomerInfo() {
        var success = true;

        for (var i = 0; i < $billing_fields.length; i++) {
          var field = $billing_fields[i];

          if (isEmpty(field.val())) {
            showError(field);
            success = false;
          }
        }

        if ($state.val() === '00') {
          showError($state);
          success = false;
        }

        if (canada_postal_code) {
          var ca_post_regex = /^[ABCEGHJKLMNPRSTVXY]{1}\d{1}[A-Z]{1} *\d{1}[A-Z]{1}\d{1}$/i;
          if (!$zip.val().match(ca_post_regex)) {
            showError($zip);
            success = false;
          }
        }

        if (!$same_as_billing.is(':checked')) {
          for (var i = 0; i < $shipping_fields.length; i++) {
            var field = $shipping_fields[i];

            if (isEmpty(field.val())) {
              showError(field);
              success = false;
            }
          }

          if ($shipping_state.val() === '00') {
            showError($shipping_state);
            success = false;
          }
        }

        return success;
      }

      function hideCustomerInfoErrors() {
        $all_errors.addClass('hidden');
        for (var i = 0; i < $billing_fields.length; i++) {
          $billing_fields[i].removeClass('error');
        }
        $state.removeClass('error');

        for (var i = 0; i < $shipping_fields.length; i++) {
          $shipping_fields[i].removeClass('error');
        }
        $shipping_state.removeClass('error');
        $phone.removeClass('error');
      }

      function handleAddressValidationSuccess(result) {
        if (!result.show_modal) {
          // Use original.
          $("input[name='billing_use_original']").val(1);
          if (!$same_as_billing.is(':checked')) {
            $("input[name='shipping_use_original']").val(1);
          }

          // Let it fall to the next submit handler (billing-info.js) if we're
          // on the combined form.
          if (isCombinedForm) {
            formContext.addClass('address-validated');
            $submit.off('click.qknCustomerInfo');
            $submit.trigger('click');
          }
          else {
            formContext.submit();
          }
          return;
        }

        if (result.markup) {
          var $popup = $(result.markup).appendTo($body);

          var $address_cancel = $('.js-modal-close', $popup);
          var $address_okay = $('.js-address-okay', $popup);

          $popup.find('.modal-box').show();

          $("input:radio[name='billing']:checked").focus();

          $address_cancel.on('click', function(e) {
            $('.modal-overlay', $body).remove();
          });

          $address_cancel.on('keypress', function (e) {
            if (e.keyCode == 13) {
              $address_cancel.click();
            }
          });

          $address_cancel.on('keydown', function (e) {
            if (e.keyCode == 9) {
              $("input:radio[name='billing']:checked").focus();
              e.preventDefault();
            }
          });

          $address_okay.on('click', function(e) {
            var $billing_address_selection = $("input:radio[name='billing']:checked").val();
            if ($billing_address_selection == null) {
              $billing_address_selection = 'billing_original';
            }

            if ($billing_address_selection !== 'billing_original') {
              var updated_billing_address = Drupal.behaviors.customerInfo.validAddresses[$billing_address_selection];

              $address.val(updated_billing_address.street[0]);
              $city.val(updated_billing_address.city);
              $zip.val(updated_billing_address.postcode);
              $state.find('option').each(function() {
                if ($(this).text() == updated_billing_address.region) {
                  $(this).attr('selected', 'selected');
                }
              });
            }
            else {
              $("input[name='billing_use_original']").val(1);
            }

            if (!$same_as_billing.is(':checked')) {
              var $shipping_address_selection = $("input:radio[name='shipping']:checked").val();
              if ($shipping_address_selection == null) {
                $shipping_address_selection = 'shipping_original';
              }

              if ($shipping_address_selection !== 'shipping_original') {
                var updated_shipping_address = Drupal.behaviors.customerInfo.validAddresses[$shipping_address_selection];

                $shipping_address.val(updated_shipping_address.street[0]);
                $shipping_city.val(updated_shipping_address.city);
                $shipping_zip.val(updated_shipping_address.postcode);
                $shipping_state.find('option').each(function() {
                  if ($(this).text() == updated_shipping_address.region) {
                    $(this).attr('selected', 'selected');
                  }
                });
              }
              else {
                $("input[name='shipping_use_original']").val(1);
              }
            }

            if (isCombinedForm) {
              $('.modal-overlay', $body).remove();
              formContext.addClass('address-validated');
            }
            $submit.off('click.qknCustomerInfo');
            $submit.trigger('click');
          });

          $address_okay.on('keypress', function (e) {
            if (e.keyCode == 13) {
              $address_okay.click();
            }
          });
        }
      }

      $submit.on('click.qknCustomerInfo', function(e) {
        hideCustomerInfoErrors();

        e.preventDefault();
        var validation = validateCustomerInfo();
        if (!validation) {
          return;
        }

        var addressIsValidated = formContext.hasClass('address-validated') || formContext.hasClass('bypass-address-validation');

        if (isCombinedForm && addressIsValidated) {
          $submit.off('click.qknCustomerInfo');
          $submit.trigger('click');
          return;
        }

        if (!addressIsValidated) {
          var $post_data = {};
          $post_data.billing = {};
          $post_data.billing.street = $address.val();
          $post_data.billing.address_2 = $address_2.val();
          $post_data.billing.city = $city.val();
          $post_data.billing.state = $state.val();
          $post_data.billing.zip = $zip.val();

          if (!$same_as_billing.is(':checked')) {
            $post_data.shipping = {};
            $post_data.shipping.street = $shipping_address.val();
            $post_data.shipping.address_2 = $shipping_address_2.val();
            $post_data.shipping.city = $shipping_city.val();
            $post_data.shipping.state = $shipping_state.val();
            $post_data.shipping.zip = $shipping_zip.val();
          }

          $.post('/shoppingcart/validate-address', $post_data, function(result) {
            handleAddressValidationSuccess(result);
          }).fail(function () {
            e.stopImmediatePropagation();
            alert('An error occurred. Please try again.');
          });
        }
        else {
          // No address validation needed.
          formContext.submit();
          return;
        }
      });
    }
  };
})(jQuery);
;
/**
 * @file
 * Custom JavaScript for Braintree checkout form.
 */

(function($) {
  Drupal.behaviors.billingInfo = {
    attach : function(context, settings) {
      var $body = $('html, body', context);
      var $braintree_form = $('.js-braintree-form', context);
      if (!$braintree_form.length) {
        return;
      }

      // Check for combined form.
      var isCombinedForm = $('body', context).hasClass('checkout-page-customer-info-combined');

      // Advanced Fraud Protection Data
      var deviceData = null;

      var $payment_error = $('#js-cart-review-error', context);

      var $ccValid = $('.js-checkout-cc', context);

      var $cvv_link = $('.js-cvv-trigger', context);
      var $cvv_copy = $('.js-cvv-copy', context);

      var $cc_name = $('#card-name-field', context);

      $cvv_link.click(function (e) {
        e.preventDefault();

        if ($cvv_copy.is(":visible")) {
          return;
        }

        $cvv_copy.fadeIn(300, function(){
          $cvv_copy.focus();
        });
      });

      $cvv_copy.blur(function (e) {
        $cvv_copy.fadeOut(300);
      });

      var $card_number_error = $('.js-card-number-error', context);
      var $card_expiration_error = $('.js-card-expiration-date-error', context);
      var $card_cvv_error = $('.js-card-security-code-error', context);
      var $card_name_error = $('.js-card-name-error', context);

      var $submit = $('.checkout-button', context);

      function checkName() {
        if ($cc_name.val() == '') {
          showBraintreeError('name');
          return false;
        } else {
          hideBraintreeError('name');
          return true;
        }
      };

      function hideAllErrors() {
        hideBraintreeError('number');
        hideBraintreeError('expirationDate');
        hideBraintreeError('cvv');
        hideBraintreeError('name');
      }

      function showBraintreeError(field_name) {
        switch(field_name) {
          case 'number':
            $card_number_error.html('Please enter a valid card number');
            $card_number_error.siblings('.braintree-field').addClass('braintree-hosted-fields-invalid');
            break;

          case 'expirationDate':
            $card_expiration_error.html('Please enter a valid expiration date');
            $card_expiration_error.siblings('.braintree-field').addClass('braintree-hosted-fields-invalid');
            break;

          case 'cvv':
            $card_cvv_error.html('Please enter valid security code');
            $card_cvv_error.siblings('.braintree-field').addClass('braintree-hosted-fields-invalid');
            break;

          case 'name':
            $card_name_error.html('Please enter your name as shown on the credit card');
            $card_name_error.siblings('.braintree-field').addClass('braintree-hosted-fields-invalid');
            break;
        }
      }

      function hideBraintreeError(field_name) {
        switch(field_name) {
          case 'number':
            $card_number_error.html('');
            $card_number_error.siblings('.braintree-field').removeClass('braintree-hosted-fields-invalid');
            break;

          case 'expirationDate':
            $card_expiration_error.html('');
            $card_expiration_error.siblings('.braintree-field').removeClass('braintree-hosted-fields-invalid');
            break;

          case 'cvv':
            $card_cvv_error.html('');
            $card_cvv_error.siblings('.braintree-field').removeClass('braintree-hosted-fields-invalid');
            break;

          case 'name':
            $card_name_error.html('');
            $card_name_error.siblings('.braintree-field').removeClass('braintree-hosted-fields-invalid');
            break;
        }
      }

      function showAllErrors() {
        var inputs = ['number', 'expirationDate', 'cvv'];
        for (var i = 0; i < inputs.length; i++) {
          showBraintreeError(inputs[i]);
        }
        $body.animate({
          scrollTop: $('#page-title', context).offset().top
        }, 1000);
      }

      function showPaymentError(r) {
        $payment_error.html(r).show();
        $body.animate({
          scrollTop: $payment_error.offset().top
        }, 1000);
      }

      // Locks out form if braintree auth fails.
      function lockoutBraintreeForm() {
        $('.js-customer-info-submit', $braintree_form).attr('disabled', 'disabled');
        $braintree_form.submit(function(){
          e.preventDefault();
          return false;
        });
      }

      function hidePaymentError() {
        $payment_error.html('').hide();
      }

      // Show error.
      if (isCombinedForm && url('?e') == 'payment_error') {
        var errorCode = url('?eMsg');
        if (errorCode in settings.quicken_checkout.error_codes) {
          // We have a valid error code.
          if (settings.quicken_checkout.error_codes[errorCode] == 'cvv') {
            hidePaymentError();
            showBraintreeError('cvv');
          }
          else {
            showPaymentError(settings.quicken_checkout.error_codes[errorCode]);
          }
        }
        else {
          // Invalid error code - show generic message.
          showPaymentError(settings.quicken_checkout.payment_error);
        }
      }
      else {
        // No error.
        hidePaymentError();
      }

      $cc_name.on('keyup', function(e) {
        checkName();
      });

      setupBraintree();

      function setupBraintree() {
        // Check if braintree is defined.
        if (typeof braintree != "object") {
          var errorMessage = settings.quicken_checkout.payment_error;
          showPaymentError(errorMessage);
          lockoutBraintreeForm();
        }

        braintree.client.create({
          authorization: Drupal.settings.quicken_checkout.braintree_token
        }, function (clientErr, clientInstance) {
          if (clientErr) {
            var errorMessage = settings.quicken_checkout.payment_error;
            showPaymentError(errorMessage);
            lockoutBraintreeForm();
            return;
          }

          braintree.dataCollector.create({
            client : clientInstance,
            kount : true
          }, function(dataCollectorErr, dataCollectorInstance) {
            // kount environment sandbox?
            deviceData = dataCollectorInstance.deviceData;
          });

          braintree.hostedFields.create({
            client : clientInstance,
            styles : {
              // Override Braintree styles
              'input': {
                'font-size': '14px'
              }
            },
            fields : {
              number : {
                selector : '#card-number-field',
                placeholder : 'XXXX XXXX XXXX XXXX'
              },
              cvv : {
                selector : '#card-security-code-field',
              },
              expirationDate : {
                selector : '#card-expiration-date-field',
                placeholder : 'MM / YY'
              }
            }
          }, function(hostedFieldsErr, hostedFieldsInstance) {
            // Event types: blur focus empty notEmpty cardTypeChange validityChange
            // v2 had all events lumped together
            hostedFieldsInstance.on('cardTypeChange', function(event) {
              if (event.cards.length === 1) {
                var cardType = event.cards[0].type;
                $ccValid
                  .removeClass('visa master-card discover jcb american-express diners-club maestro')
                  .addClass(cardType);
              } else {
                // Card type not known yet, remove all
                $ccValid.removeClass('visa master-card discover jcb american-express diners-club maestro');
              }
            });
            hostedFieldsInstance.on('blur', function(event) {
              var field = event.fields[event.emittedBy];
              if (!field.isEmpty && (field.isValid || field.isPotentiallyValid)) {
                hideBraintreeError(event.emittedBy);
              }
              else {
                showBraintreeError(event.emittedBy);
              }
            });
            hostedFieldsInstance.on('validityChange', function(event) {
              var field = event.fields[event.emittedBy];

              if (field.isValid || field.isPotentiallyValid) {
                hideBraintreeError(event.emittedBy);
              }
              else {
                showBraintreeError(event.emittedBy);
              }
            });

            $braintree_form.on('submit.qknBraintree', function(event) {
              event.preventDefault();

              hideAllErrors();
              hidePaymentError();
              if (checkName() === false) {
                $body.animate({
                  scrollTop: $('#page-title', context).offset().top
                }, 1000);
                return;
              }

              hostedFieldsInstance.tokenize(function (tokenizeErr, payload) {
                if (tokenizeErr) {
                  switch (tokenizeErr.code) {
                    case 'HOSTED_FIELDS_FIELDS_EMPTY':
                      // occurs when none of the fields are filled in

                      showAllErrors();

                      break;
                    case 'HOSTED_FIELDS_FIELDS_INVALID':
                      // occurs when certain fields do not pass client side validation

                      tokenizeErr.details.invalidFieldKeys.map(function(item) {
                        showBraintreeError(item);
                      });

                      break;
                    case 'HOSTED_FIELDS_TOKENIZATION_FAIL_ON_DUPLICATE':
                      // occurs when:
                      //   * the client token used for client authorization was generated
                      //     with a customer ID and the fail on duplicate payment method
                      //     option is set to true
                      //   * the card being tokenized has previously been vaulted (with any customer)
                      // See: https://developers.braintreepayments.com/reference/request/client-token/generate/#options.fail_on_duplicate_payment_method

                      showPaymentError(settings.quicken_checkout.payment_error);

                      break;
                    case 'HOSTED_FIELDS_TOKENIZATION_CVV_VERIFICATION_FAILED':
                      // occurs when:
                      //   * the client token used for client authorization was generated
                      //     with a customer ID and the verify card option is set to true
                      //     and you have credit card verification turned on in the Braintree
                      //     control panel
                      //   * the cvv does not pass verfication (https://developers.braintreepayments.com/reference/general/testing/#avs-and-cvv/cid-responses)
                      // See: https://developers.braintreepayments.com/reference/request/client-token/generate/#options.verify_card

                      showBraintreeError('cvv');

                      break;
                    case 'HOSTED_FIELDS_FAILED_TOKENIZATION':
                      // occurs for any other tokenization error on the server

                      showPaymentError(settings.quicken_checkout.payment_error);

                      break;
                    case 'HOSTED_FIELDS_TOKENIZATION_NETWORK_ERROR':
                      // occurs when the Braintree gateway cannot be contacted

                      showPaymentError(settings.quicken_checkout.payment_error);

                      break;
                    default:
                      showPaymentError(settings.quicken_checkout.payment_error);
                  }
                  $body.animate({
                    scrollTop: $('#page-title', context).offset().top
                  }, 1000);
                  return;
                }

                var post_data = {};
                var nonce = payload.nonce;
                var name_on_card = $('#card-name-field', context).val();

                post_data['quicken_checkout_billing_nonce'] = nonce;
                post_data['quicken_checkout_billing_card_name'] = name_on_card;

                if (payload.details) {
                  post_data['quicken_checkout_billing_card_type'] = payload.details.cardType;
                  post_data['quicken_checkout_billing_card_digits'] = payload.details.lastTwo;
                }

                if (deviceData) {
                  post_data['quicken_checkout_billing_device_data'] = deviceData;
                }

                if (isCombinedForm) {
                  // Combined form, let the form submit handler do all the stuff.
                  $.each(post_data, function(key, value){
                    $('input[name="' + key + '"]', $braintree_form).val(value);
                  });
                  $braintree_form.off('submit.qknBraintree');
                  $braintree_form.trigger('submit');
                }
                else {
                  // Disable submit button while processing.
                  $submit.attr('disabled', 'disabled');

                  // Not combined form, use AJAX callback handler.
                  $.post(Drupal.settings.quicken_checkout.billing_callback, post_data, function (result) {
                    if (!result.success) {
                      if (result.card_error) {
                        if (result.card_error == 'cvv') {
                          // Invalid CVV.
                          showBraintreeError('cvv');
                        }
                        else {
                          // Standard error.
                          showPaymentError(result.card_error);
                        }
                        $submit.removeAttr('disabled');
                        return;
                      }

                      if (result.connection_error) {
                        window.location = '/'  + Drupal.settings.quicken_checkout.error_path;
                        return;
                      }
                    }
                    else {
                      // Success!
                      window.location = '/'  + Drupal.settings.quicken_checkout.review_path;
                    }
                  });
                }
              });
            });
          });
        });
      }
    }
  };
})(jQuery);
;
/**
 * @file
 * Custom JavaScript to submit the order to Magento.
 */

(function($) {
  Drupal.behaviors.checkoutReview = {
    attach : function(context, settings) {
      var $body = $('body', context);
      var $checkout_button = $('.js-quicken-checkout-button', context);
      if ($checkout_button.length < 1) {
        return;
      }

      // Scroll screen to H1 on first load.
      $('html, body').animate({
        scrollTop: $('#page-title', context).offset().top
      }, 700);

      var $cart_review_error = $('#js-cart-review-error', context);
      var $loader = [];

      $loader += '<div class="loader-wrap">';
      $loader += '<div class="loader">Your order is being processed…</div>';
      $loader += '</div>';

      function showPaymentError(err) {
        $cart_review_error.html(err).show();
      }

      function hidePaymentError() {
        $cart_review_error.html('').hide();
      }

      function showLoader() {
        if ($('.loader-wrap', context).length < 1) {
          $body.append($loader);
        }
      }

      function hideLoader() {
        $('.loader-wrap', context).remove();
      }

      hidePaymentError();

      $checkout_button.click(function (e) {
        e.preventDefault();
        $(this).addClass('disabled');
        showLoader();
        hidePaymentError();

        $.post(Drupal.settings.quicken_checkout.place_order_callback, {}, function (result) {
          if (result.error) {
            hideLoader();
            showPaymentError(result.error);
            $body.animate({
              scrollTop: $cart_review_error.offset().top
            }, 1500);
          }

          if (result.fatal_error) {
            window.location = '/'  + Drupal.settings.quicken_checkout.error_path;
          }

          if (result.success) {
            window.location = '/'  + Drupal.settings.quicken_checkout.confirmation_path;
          }
        });
      });
    }
  };
})(jQuery);
;
